diff --git a/Makefile b/Makefile
index a0bf1ec..8a9c13f 100644
--- a/Makefile
+++ b/Makefile
@@ -48,7 +48,7 @@ CHIP_OBJS = jedec.o stm50flw0x0x.o w39v080fa.o sharplhf00l04.o w29ee011.o \
 
 LIB_OBJS = layout.o
 
-CLI_OBJS = flashrom.o cli_classic.o print.o
+CLI_OBJS = flashrom.o cli_classic.o cli_output.o print.o
 
 PROGRAMMER_OBJS = udelay.o programmer.o
 
diff --git a/cli_output.c b/cli_output.c
new file mode 100644
index 0000000..ae44920
--- /dev/null
+++ b/cli_output.c
@@ -0,0 +1,51 @@
+/*
+ * This file is part of the flashrom project.
+ *
+ * Copyright (C) 2009 Sean Nelson <audiohacked@gmail.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ */
+
+#include <stdio.h>
+#include <stdarg.h>
+#include "flash.h"
+
+int print(int type, const char *fmt, ...)
+{
+	va_list ap;
+	int ret;
+	FILE *output_type;
+	
+	switch (type)
+	{
+	case MSG_DEBUG:
+		if (!verbose) return 0;
+		output_type = stdout;
+		break;
+	case MSG_ERROR:
+		output_type = stderr;
+		break;
+	case MSG_INFO:
+		default:
+		output_type = stdout;
+		break;
+	}
+	
+	va_start(ap, fmt);
+	ret = vfprintf(output_type, fmt, ap);
+	va_end(ap);
+	return ret;
+}
+
diff --git a/flash.h b/flash.h
index 648dc83..56c7588 100644
--- a/flash.h
+++ b/flash.h
@@ -504,6 +504,14 @@ int doit(struct flashchip *flash, int force, char *filename, int read_it, int wr
 #define OK 0
 #define NT 1    /* Not tested */
 
+/* cli_print.c */
+int print(int type, const char *fmt, ...);
+
+#define MSG_INFO 0
+#define MSG_DEBUG 1
+#define MSG_SPEW 2
+#define MSG_ERROR 3
+
 /* cli_classic.c */
 int cli_classic(int argc, char *argv[]);
 
